@@ -7,16 +7,14 @@ Establish a connection to the database
 import logging
 
 from pymongo import MongoClient
-from pymongo.errors import ConnectionFailure, ServerSelectionTimeoutError
+from pymongo.errors import ConnectionFailure, OperationFailure, ServerSelectionTimeoutError
 
 try:
-    # Python 3.x
     from urllib.parse import quote_plus
 except ImportError:
     # Python 2.x
     from urllib import quote_plus
 
-
 LOG = logging.getLogger(__name__)
 
 
@@ -30,7 +28,7 @@ def get_connection(
     authdb=None,
     timeout=20,
     *args,
-    **kwargs
+    **kwargs,
 ):
     """Get a client to the mongo database
 
@@ -44,21 +42,20 @@ def get_connection(
 
     """
     authdb = authdb or mongodb
+
     if uri is None:
         if username and password:
             uri = "mongodb://{}:{}@{}:{}/{}".format(
                 quote_plus(username), quote_plus(password), host, port, authdb
             )
-            log_uri = "mongodb://{}:****@{}:{}/{}".format(quote_plus(username), host, port, authdb)
         else:
-            log_uri = uri = "mongodb://%s:%s" % (host, port)
+            uri = "mongodb://%s:%s" % (host, port)
 
-    LOG.info("Try to connect to %s" % log_uri)
+    client = MongoClient(uri, serverSelectionTimeoutMS=timeout)
     try:
-        client = MongoClient(uri, serverSelectionTimeoutMS=timeout)
-    except ServerSelectionTimeoutError as err:
-        LOG.warning("Connection Refused")
-        raise ConnectionFailure
+        server_info = client.server_info()
+        LOG.info(f"Connected to MongoDB {server_info.get('version')}")
+    except (ServerSelectionTimeoutError, OperationFailure, ConnectionFailure) as err:
+        LOG.warning(f"Database connection error:{err}")
 
-    LOG.info("Connection established")
     return client
