@@ -1,3 +1,46 @@
+VARIANT_REPORT_VARIANT_FEATURES = [
+    "_id",
+    "variant_id",
+    "display_name",
+    "sanger_ordered",
+    "validation",
+    "phenotypes",
+    "chromosome",
+    "position",
+    "end",
+    "end_chrom",
+    "cytoband_start",
+    "cytoband_end",
+    "reference",
+    "alternative",
+    "dbsnp_id",
+    "panels",
+    "samples",
+    "frequency",
+    "dbsnp_id",
+    "thousandg_link",
+    "thousand_genomes_frequency",
+    "max_thousand_genomes_frequency",
+    "max_exac_frequency",
+    "exac_frequency",
+    "gnomad_frequency" "variant_rank",
+    "rank_score",
+    "manual_rank",
+    "cancer_tier",
+    "cadd_score",
+    "genetic_models",
+    "acmg_classification",
+    "genes",
+    "comments",
+    "category",
+    "dismiss_variant",
+    "variant_rank",
+    "str_repid",
+    "str_display_ru",
+    "str_ru",
+    "str_status",
+]
+
 CONSEQUENCE = (
     "deleterious",
     "deleterious_low_confidence",
