@@ -72,7 +72,7 @@ variant = dict(
     local_frequency=float,
     local_obs_old=int,
     local_obs_hom_old=int,
-    local_obs_total_old=int,  # default=638
+    local_obs_total_old=int,
     # Predicted deleteriousness:
     cadd_score=float,
     clnsig=list,  # list of <clinsig>
