@@ -24,13 +24,16 @@ from scout.constants import (
     DISMISS_VARIANT_OPTIONS,
     MANUAL_RANK_OPTIONS,
     MOSAICISM_OPTIONS,
-    SO_TERMS,
     VARIANT_FILTERS,
 )
 from scout.constants.variants_export import EXPORT_HEADER, VERIFIED_VARIANTS_HEADER
 from scout.export.variant import export_verified_variants
-from scout.server.blueprints.variant.utils import clinsig_human, predictions
-from scout.server.links import cosmic_link, str_source_link
+from scout.server.blueprints.variant.utils import (
+    clinsig_human,
+    predictions,
+    update_representative_gene,
+)
+from scout.server.links import cosmic_links, str_source_link
 from scout.server.utils import case_append_alignments, institute_and_case, user_institutes
 
 from .forms import CancerFiltersForm, FiltersForm, StrFiltersForm, SvFiltersForm, VariantFiltersForm
@@ -409,25 +412,12 @@ def parse_variant(
         variant_obj["end_chrom"] = variant_obj["chromosome"]
 
     # variant level links shown on variants page
-    variant_obj["cosmic_link"] = cosmic_link(variant_obj)
+    variant_obj["cosmic_links"] = cosmic_links(variant_obj)
     variant_obj["str_source_link"] = str_source_link(variant_obj)
     # Format clinvar information
     variant_obj["clinsig_human"] = clinsig_human(variant_obj) if variant_obj.get("clnsig") else None
-    # Set the gene with most severe consequence as being representative
-    # used for display purposes
-    if variant_genes:
-        first_rep_gene = min(
-            variant_genes, key=lambda gn: SO_TERMS[gn["functional_annotation"]]["rank"]
-        )
-        # get HGVNp identifier from the canonical transcript
-        hgvsp_identifier = None
-        for tc in first_rep_gene["transcripts"]:
-            if tc["is_canonical"]:
-                hgvsp_identifier = tc.get("protein_sequence_name")
-        first_rep_gene["hgvsp_identifier"] = hgvsp_identifier
-        variant_obj["first_rep_gene"] = first_rep_gene
-    else:
-        variant_obj["first_rep_gene"] = None
+
+    update_representative_gene(variant_obj, variant_genes)
 
     # annotate filters
     variant_obj["filters"] = [
