@@ -49,7 +49,7 @@ def variants(institute_id, case_name):
     category = "snv"
     institute_obj, case_obj = institute_and_case(store, institute_id, case_name)
     variant_type = request.args.get("variant_type", "clinical")
-    variants_stats = store.case_variants_count(case_obj["_id"], institute_id, False)
+    variants_stats = store.case_variants_count(case_obj["_id"], institute_id, variant_type, False)
 
     if request.form.get("hpo_clinical_filter"):
         case_obj["hpo_clinical_filter"] = True
@@ -152,7 +152,7 @@ def str_variants(institute_id, case_name):
     category = "str"
 
     institute_obj, case_obj = institute_and_case(store, institute_id, case_name)
-    variants_stats = store.case_variants_count(case_obj["_id"], institute_id, False)
+    variants_stats = store.case_variants_count(case_obj["_id"], institute_id, variant_type, False)
 
     user_obj = store.user(current_user.email)
 
@@ -200,6 +200,9 @@ def str_variants(institute_id, case_name):
 
     result_size = store.count_variants(case_obj["_id"], query, None, category)
 
+    if request.form.get("export"):
+        return controllers.download_str_variants(case_obj, variants_query)
+
     data = controllers.str_variants(
         store, institute_obj, case_obj, variants_query, result_size, page
     )
@@ -230,7 +233,7 @@ def sv_variants(institute_id, case_name):
     category = "sv"
     # Define case and institute objects
     institute_obj, case_obj = institute_and_case(store, institute_id, case_name)
-    variants_stats = store.case_variants_count(case_obj["_id"], institute_id, False)
+    variants_stats = store.case_variants_count(case_obj["_id"], institute_id, variant_type, False)
 
     if request.form.get("hpo_clinical_filter"):
         case_obj["hpo_clinical_filter"] = True
@@ -300,7 +303,7 @@ def cancer_variants(institute_id, case_name):
     category = "cancer"
     variant_type = request.args.get("variant_type", "clinical")
     institute_obj, case_obj = institute_and_case(store, institute_id, case_name)
-    variants_stats = store.case_variants_count(case_obj["_id"], institute_id, False)
+    variants_stats = store.case_variants_count(case_obj["_id"], institute_id, variant_type, False)
 
     user_obj = store.user(current_user.email)
     if request.method == "POST":
@@ -405,7 +408,7 @@ def cancer_sv_variants(institute_id, case_name):
     category = "cancer_sv"
     # Define case and institute objects
     institute_obj, case_obj = institute_and_case(store, institute_id, case_name)
-    variants_stats = store.case_variants_count(case_obj["_id"], institute_id, False)
+    variants_stats = store.case_variants_count(case_obj["_id"], institute_id, variant_type, False)
 
     if request.form.get("hpo_clinical_filter"):
         case_obj["hpo_clinical_filter"] = True
